.. TBriDGE documentation master file, created by
   sphinx-quickstart on Thu Nov  5 17:05:24 2020.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

TBriDGE Documentation
===================================

.. toctree::
   :maxdepth: 2

   docs/config.rst
   docs/simulating_galaxies.rst
   docs/pipelines.rst
   
   docs/source/tbridge.rst


.. note::

   TBriDGE is stil a work in progress and many methods, though feature complete and
   should be completely free of bugs, are in need of continued optimization.